Basic test with editor
open | / |
type | projectname | seleniumtest
clickAndWait | startprojectbutton |
click | openeditor |
type | editorcontents | Dit is een test.
select | editorinputtemplate | label=Input text document
select | language | label=Dutch
type | editorfilename | test
click | editorsubmit |
waitForTextPresent | test.txt |
verifyTextPresent | Input text document |
click | createlexicon |
clickAndWait | //input[@value='Start'] |
waitForTextPresent | The system is running |
waitForTextPresent | Done |
verifyTextPresent | overall.freqlist |
verifyTextPresent | overall.stats |
verifyTextPresent | test.txt.freqlist |
verifyTextPresent | test.txt.stats |
verifyTextPresent | Overall Frequency List |
verifyTextPresent | Overall Statistics |
verifyTextPresent | Document Frequency list |
verifyTextPresent | Document Statistics |
clickAndWait | abortbutton |
verifyTextPresent | Start a new Project |